@@ -101,8 +101,8 @@ pub struct SubjectMedium {
     pub air_date: String,
     pub air_weekday: u8,
     pub images: SubjectImage,
-    pub eps: u32,
-    pub eps_count: u32,
+    pub eps: Option<u32>,
+    pub eps_count: Option<u32>,
     pub rating: SubjectRating,
     pub rank: u32,
     pub collection: SubjectCollection,
