@@ -32,7 +32,7 @@ const INDENTS: &str = "                        "; // 24 spaces
 const INDENTS_WIDTH: usize = 2;
 
 pub fn indent(i: usize) -> &'static str {
-    &INDENTS[..std::cmp::min(i * INDENTS_WIDTH, (&INDENTS).len())]
+    &INDENTS[..std::cmp::min(i * INDENTS_WIDTH, INDENTS.len())]
 }
 
 pub fn indent_display(f: &std::fmt::Formatter<'_>) -> &'static str {
@@ -46,49 +46,49 @@ pub fn indent_display(f: &std::fmt::Formatter<'_>) -> &'static str {
 #[macro_export]
 macro_rules! info {
     (ind: $ind:expr, $($arg:tt)+) => {
-        log::info!("{}{}", $crate::logger::indent($ind), format!($($arg)+));
+        log::info!("{}{}", $crate::logger::indent($ind), format!($($arg)+))
     };
     ($($arg:tt)+) => {
-        log::info!($($arg)+);
+        log::info!($($arg)+)
     }
 }
 
 #[macro_export]
 macro_rules! error {
     (ind: $ind:expr, $($arg:tt)+) => {
-        log::error!("{}{}", $crate::logger::indent($ind), colored::Colorize::red(&*format!($($arg)+)));
+        log::error!("{}{}", $crate::logger::indent($ind), colored::Colorize::red(&*format!($($arg)+)))
     };
     ($($arg:tt)+) => {
-        log::error!($($arg)+);
+        log::error!($($arg)+)
     }
 }
 
 #[macro_export]
 macro_rules! debug {
     (ind: $ind:expr, $($arg:tt)+) => {
-        log::debug!("{}{}", $crate::logger::indent($ind), format!($($arg)+));
+        log::debug!("{}{}", $crate::logger::indent($ind), format!($($arg)+))
     };
     ($($arg:tt)+) => {
-        log::debug!($($arg)+);
+        log::debug!($($arg)+)
     }
 }
 
 #[macro_export]
 macro_rules! trace {
     (ind: $ind:expr, $($arg:tt)+) => {
-        log::trace!("{}{}", $crate::logger::indent($ind), format!($($arg)+));
+        log::trace!("{}{}", $crate::logger::indent($ind), format!($($arg)+))
     };
     ($($arg:tt)+) => {
-        log::trace!($($arg)+);
+        log::trace!($($arg)+)
     }
 }
 
 #[macro_export]
 macro_rules! warn {
     (ind: $ind:expr, $($arg:tt)+) => {
-        log::warn!("{}{}", $crate::logger::indent($ind), colored::Colorize::yellow(&*format!($($arg)+)));
+        log::warn!("{}{}", $crate::logger::indent($ind), colored::Colorize::yellow(&*format!($($arg)+)))
     };
     ($($arg:tt)+) => {
-        log::warn!($($arg)+);
+        log::warn!($($arg)+)
     }
 }
